/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.L1.AtmsSdrConstant.java
*
* NAME
*   atms.L1.AtmsSdrConstant.java
*
* PURPOSE
*   Defines constants for ATMS GEO/TDR data 
* 
* DESCRIPTION
*	This class is used to define constants of ATMS GEO/TDR measurements.
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */

package atms.L1;


/**
 * Define constants for ATMS SDR
 * @author Xianjun Hao, George Mason University  
 */
public class AtmsSdrConstant {
    /**
     *  Number of foot prints per scan
     */
    final  public static int NUMBER_FOOTPRINTS_PER_SCAN = 96;
       
    /**
     * Variable path of SDR file
     */
    final public static String SDR_VARPATH="/All_Data/ATMS-SDR_All/";
    
    /**
     * Variable name of brightness temperature in SDR file
     */
    final public static String SDR_VARNAME_BT = "BrightnessTemperature";
    
    /**
     * Variable name of brightness temperature factors in SDR file
     */
    final public static String SDR_VARNAME_BT_FACTORS = "BrightnessTemperatureFactors";
    
    /**
     * Variable name of beam time factors in SDR file
     */
    final public static String SDR_VARNAME_BEAM_TIME = "BeamTime";

    /**
     * Variable path of geolocation file
     */
    final public static String GEO_VARPATH="/All_Data/ATMS-SDR-GEO_All/";
    
    /**
     * Variable name of latitude in geolocation file
     */
    final public static String GEO_VARNAME_LATITUDE = "Latitude";

    /**
     * Variable name of latitude in geolocation file
     */
    final public static String GEO_VARNAME_LONGITUDE = "Longitude";

    /**
     * Variable name of SatelliteZenithAngle in geolocation file
     */
    final public static String GEO_SENSOR_ZENITH_ANGLE = "SatelliteZenithAngle";

    /**
     * Variable name of SatelliteAzimuthAngle in geolocation file
     */
    final public static String GEO_SENSOR_AZIMUTH_ANGLE = "SatelliteAzimuthAngle";
    
    /**
     * Variable name of SolarZenithAngle in geolocation file
     */
    final public static String GEO_SOLAR_ZENITH_ANGLE = "SolarZenithAngle";

    /**
     * Variable name of SolarAzimuthAngle in geolocation file
     */
    final public static String GEO_SOLAR_AZIMUTH_ANGLE = "SolarAzimuthAngle";
    
    /**
     * Orbit type: ascending
     */
    final public static int ORBIT_TYPE_ASCENDING = 0;
    
    /**
     * Orbit type: descending
     */
    final public static int ORBIT_TYPE_DESCENDING = 1;
    
}

