/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.L3.GriddedAtmsData.java
*
* NAME
*   atms.L3.GriddedAtmsData.java
*
* PURPOSE
*   Define data structure of the monthly gridded ATMS TDR data
* 
* DESCRIPTION
*   This class is used to define data structure of the monthly gridded L3 file.
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */
package atms.L3;

import static atms.etc.AtmsGridConstant.GRID_NUM_LAT;
import static atms.etc.AtmsGridConstant.GRID_NUM_LON;
import static atms.etc.AtmsGridConstant.NUMBER_SELECTED_CHANNELS;

import atms.etc.*;
import atms.L1.*;
import atms.config.AtmsTaskConfig;
import atms.util.*;

/** 
 * Gridded data
 * @author Xianjun Hao, George Mason University
 */
public class GriddedAtmsData {
    /**
     * Mean of Gridded ATMS data
     */
    public float[][][] bt_gridded_mean = null;

    /**
     * Standard deviation of Gridded ATMS data
     */
    public float[][][] bt_gridded_std = null;
    
    /**
     * BT for minvza of Gridded ATMS data
     */
    public float[][][] bt_gridded_minvza = null;
 
    /**
     * MINVZA
     */
    public float[][][] minvza_gridded = null;
    
    /**
     *  pixel count of valid data
     */
    public int[][][] pc_gridded = null;

    /**
     * Constructor.
     */
    public GriddedAtmsData(){
        int i =0;
        int j = 0;
        int k = 0;
        // data dimension: channel, latitude, longitude
        this.bt_gridded_mean = new float[NUMBER_SELECTED_CHANNELS][GRID_NUM_LAT][GRID_NUM_LON];
        this.bt_gridded_minvza = new float[NUMBER_SELECTED_CHANNELS][GRID_NUM_LAT][GRID_NUM_LON];
        this.bt_gridded_std = new float[NUMBER_SELECTED_CHANNELS][GRID_NUM_LAT][GRID_NUM_LON];
        this.pc_gridded = new int[NUMBER_SELECTED_CHANNELS][GRID_NUM_LAT][GRID_NUM_LON];
        this.minvza_gridded = new float[NUMBER_SELECTED_CHANNELS][GRID_NUM_LAT][GRID_NUM_LON];      
        
        for(k=0; k<NUMBER_SELECTED_CHANNELS; k++) {
            for (i=0; i<GRID_NUM_LAT; i++) {
                for(j=0; j<GRID_NUM_LON; j++) {
                    this.bt_gridded_mean[k][i][j] = 0.0f;
                    this.bt_gridded_minvza[k][i][j] = 0.0f;
                    this.bt_gridded_std[k][i][j] = 0.0f;
                    this.pc_gridded[k][i][j] = 0;
                    this.bt_gridded_minvza[k][i][j] = 0.0f;                    
                }
            }
        }                
    }    
    
    /**
     * Check pixel count
     */
    public void checkPixelCount(){
        int i = 0;
        int j=0;
        int k = 0;
        int num = 0;
        int pcMin = Integer.MAX_VALUE;
        int pcMax = 0;
  
        String str = "";
        
        for(k=0; k<NUMBER_SELECTED_CHANNELS; k++) {
            pcMin = Integer.MAX_VALUE;
            pcMax  = 0;
            for(i=0; i<GRID_NUM_LAT; i++) {
                for(j=0; j<GRID_NUM_LON; j++) {
                    num = this.pc_gridded[k][i][j];
                    if (pcMin > num) {
                        pcMin = num;
                    }
                    
                    if(pcMax<num) {
                        pcMax = num;
                    }
                }
            }
            str = String.format("Channel %02d count: %4d, %4d ",k, pcMin, pcMax);
            System.out.println(str);
        }
        
    }   
}
