/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.L4.AtmsTdrL4.java
*
* NAME
*   atms.L4.AtmsTdrL4.java
*
* PURPOSE
*   Generate time series of the monthly gridded ATMS TDR data 
* 
* DESCRIPTION
*	This is the main class is to generate netcdf files for the time series of the monthly gridded ATMS TDR data.
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */

package atms.L4;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 *  Main class  to generate netcdf files for the time series of the monthly gridded ATMS TDR data.
 * @author Xianjun Hao, George Mason University
 */
public class AtmsTdrL4 {


    /**
     * Logger for errors
     */
    final static private  Logger  errLogger = LogManager.getLogger("ErrorLog");
    
    /**
     * Logger for information
     */
    final static private  Logger  infoLogger = LogManager.getLogger("InfoLog");    
    /**
     * Main method to produce ATMS L4 data.
     * @param args, task parameters. 
     */
    public static void main(String[] args) {
        int year1 = 2011;
        int month1 = 11;
        int year2 = 2018;
        int month2 = 3;
        int channel = 8;
        int k =0;
        String satName = "npp";
        String dirL3="/home/xhao/data/mltcdrv5/data/L3";
        String dirL4="/home/xhao/data/mltcdrv5/data/L4";
        
        for(k=0; k<args.length; k++) {
            String str1=String.format("args[%d]=%s", k, args[k]);
            System.out.println(str1);
        }
        
        if (args.length>=8) {
            k=0;
            satName = args[k++];
            channel = Integer.parseInt(args[k++]);
            year1 = Integer.parseInt(args[k++]);
            month1 = Integer.parseInt(args[k++]);
            year2 = Integer.parseInt(args[k++]);
            month2 = Integer.parseInt(args[k++]);
            dirL3 = args[k++];
            dirL4 = args[k++];
        } 
        
        FileGriddedAtmsL4 fileL4 = new FileGriddedAtmsL4(satName,  channel,  year1,  month1,  year2,  month2, dirL3, dirL4);
        boolean ret = fileL4.writeL4DataToFile();
        if (ret) {
            infoLogger.info("write L4 file successfully");
        } else {
            errLogger.error("failed to write L4 file");            
        }
    }   
    
}
