/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.config.AtmsTaskConfig.java
*
* NAME
*   atms.config.AtmsTaskConfig.java
*
* PURPOSE
*   Define the task for ATMS data processing 
* 
* DESCRIPTION
*	This class is used to define the task for ATMS data processing
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */
package atms.config;

import atms.etc.JPSSConstant;

/**
 * Class to define task configuration.
 * 
 * @author Xianjun Hao, George Mason University
 */
public class AtmsTaskConfig {
    /**
     * Root directory of ATMS geolocation data
     */
    public String rootAtmsGeo = null;

    /**
     * Root directory of ATMS TDR data
     */    
    public String rootAtmsTdr = null;
    
    /**
     * Root directory of ATMS gridded data
     */    
    public String rootAtmsGridded = null;   

    /**
     * Root directory of ATMS look-up tables
     */    
    public String rootAtmsLut = null;
    
    /**
     * satellite name
     */    
    public String taskSatellite = JPSSConstant.SATELLITE_NAME_SNPP;
    
    /**
     * Number of threads
     */
    public int NumberOfThreads = 4;
    
    /**
     * Year of the start time
     */
    public int yearStart = 0;
    
    /**
     * Month of the start time
     */
    public int monthStart  = 0;
    
    /**
     * Year of the end time
     */
    public int yearEnd = 0;
    
    /**
     * Month of the end time
     */
    public int monthEnd = 0;
    
    /**
     * Flag for precipitation screening
     */
    public boolean precipitationScreening = false;
    
    /**
     * Number of months to be processed
     */
    public int numMonth = 0;
    
    /**
     * Year list 
     */
    public int[] fyear;
    
    /**
     * Month list
     */
    public int[] fmonth;
    
    /**
     * Constructor.
     * @param satName, satellite name 
     */
    public void setTaskSatellite(String satName) {
        taskSatellite = satName.trim();
    }   

    /**
     * Get satellite name
     * @return , satellite name
     */
    public String getTaskSatellite() {
        return taskSatellite;
    }   
    
    /**
     * Setup month list for processing
     */
    public void setupMonthList(){
        int year1 = this.yearStart;
        int month1 = this.monthStart;
        int year2 = this.yearEnd;
        int month2 = this.monthEnd;
        
        int km = 0;
        int kt = 0;
        int nm = 12;
        String msg;
        
        this.numMonth = (year2 - year1)*12 + (month2 - month1 +1);
        if (this.numMonth < 1){            
            System.out.println("Start and end time incorrect, task terminated.");
        } else {
            this.fyear = new int[this.numMonth];
            this.fmonth = new int[this.numMonth];
            
            for(int k=0; k<this.numMonth; k++) {
                kt = month1 + k;
                km = Math.floorMod(kt, nm);
                if (km==0){
                    km=12;
                }
                fyear[k] =  Math.floorDiv(kt-km, nm) + year1;
                fmonth[k] = km;
            }
        }

        /* checking
        for(int k=0; k<this.numMonth; k++) {
            msg = String.format("fyear,fmonth: %4d-%02d", fyear[k], fmonth[k]);
            System.out.println(msg);
        }
        */
    }
}