/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.etc.AtmsGridConstant.java
*
* NAME
*   atms.etc.AtmsGridConstant.java
*
* PURPOSE
*   Defines constants for the ATMS gridded data
* 
* DESCRIPTION
*	This class is used to define constants for the ATMS girdded data.
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */

package atms.etc;


/**
 * Define constants for ATMS gridded TDR
 * @author Xianjun Hao, George Mason University  
 */
public class AtmsGridConstant {
    /**
     * Filled values
     */
    final public static double FILLED_VALUE_BRIGHTNESS_TEMPERATURE = -9999.0d;

    /**
     * NUmber of selected channels
     */
    final public static int NUMBER_SELECTED_CHANNELS = 22;
    
    /**
     * Starting latitude of the grid.
     */
    final public static double GRID_LATITUDE_START = 90.0d;

    /**
     * End latitude of the grid.
     */
    final public static double GRID_LATITUDE_END = -90.0d;

    /**
     * Starting longitude of the grid.
     */
    final public static float GRID_LONGITUDE_START = -180.0f;

    /**
     * End longitude of the grid.
     */
    final public static float GRID_LONGITUDE_END = 180.0f;

    /**
     * Step of latitude for gridding.
     */
    final public static float GRID_STEP_LATITUDE = -2.5f;

    /**
     * Step of longitude for gridding.
     */
    final public static float GRID_STEP_LONGITUDE = 2.5f;

    
    /**
     * Number of gridding samples in latitude.
     */
    final public static int GRID_NUM_LAT = 72;

    /**
     * Number of gridding samples in longitude.
     */
    final public static int GRID_NUM_LON = 144;

    /**
     * Maximum latitude.
     */
    final public static float GRID_MAXIMUM_LATITUDE = 90.0f;

    /**
     * Minimum latitude.
     */
    final public static float GRID_MINIMUM_LATITUDE = -90.0f;

    /**
     * Maximum longitude.
     */
    final public static float GRID_MAXIMUM_LONGITUDE = 180.0f;

    /**
     * Minimum longitude.
     */
    final public static float GRID_MINIMUM_LONGITUDE = -180.0f;

    /**
     * Filled value for invalid index.
     */
    final public static int GRID_INVALID_INDEX = -999;
    
    /**
     * Filled value for invalid VZA
     */
    final public static float FILLED_VALUE_INVALID_VZA = -9999.0f;
    
    /**
     * Filled value for invalid brightness temperature.
     */
    final public static float FILLED_VALUE_INVALID_BRIGHTNESS_TEMPERATURE = -9999.0f;
    
    /**
     *  Minimum value of valid brightness temperature.
     */
     final public static float VALID_MIN_BRIGHTNESS_TEMPERATURE = 150.0f;

    /**
     *  Maximum value of valid brightness temperature.
     */
     final public static float VALID_MAX_BRIGHTNESS_TEMPERATURE = 330.0f;
     
     /**
      * 
      */
     final public static int ATMS_TDR_BRIGHTNESS_TEMPERATURE_FILLED_VALUE = 65529;
     
    /**
     * Name for ascending orbit.
     */
    final public static String ORBIT_ASCENDING_NAME = "ascending";

    /**
     * Name for descending orbit.
     */
    final public static String ORBIT_DESCENDING_NAME = "descending";

    /**
     * Flag for all orbit.
     */
    final public static short ORBIT_FLAG_ALL = 0;
    
    
    /**
     * Flag for ascending orbit.
     */
    final public static short ORBIT_FLAG_ASCENDING = 1;

    /**
     * Flag for descending orbit.
     */
    final public static short ORBIT_FLAG_DESCENDING = 2;
    
  
    /**
     * ID of composition method 1, most nadir pixel, in mapping level1 ATMS to
     * gridded FCDR.
     */
    final public static short ID_METHOD_OMPOSITION_MOST_NADIR = 1;

    /**
     * Name of composition method 1, most nadir pixel, in mapping level1 ATMS
     * to gridded ATMS.
     */
    final public static String Name_METHOD_COMPOSITION_MOST_NADIR = "Minvza";

    /**
     * ID of composition method 2, block mean, in mapping level-1 ATMS to
     * gridded ATMS.
     */
    final public static short ID_METHOD_COMPOSITION_BLOCK_MEAN = 2;

    /**
     * Name of composition method 2, block mean, in mapping level-1 ATMS to
     * gridded ATMS.
     */
    final public static String NAME_METHOD_FCDR_OMPOSITION_SPATIAL_MEAN = "Blockmean";
 
    /**
     * Threshold used for orbit determination
     */
    final public static double ORBIT_POLAR_LATITUDE = 81.0d;
    
    
    /**
     * Filled value for invalid VZA
     */
    final public static float FILLED_VALUE_INVALID_LATITUDE = -9999.0f;

    
    /**
     *  Threshold to determine valid latitude change
     */
    final public static double THRESHOLD_DELTA_LATITUDE = -1000.0d; 
    
    /**
     * Nadir scan position at left
     */
    final public static int INDEX_SCAN_NADIR_LEFT = 47;
    
    /**
     * Nadir scan position at right
     */
    final public static int INDEX_SCAN_NADIR_RIGHT = 48;
        
    /**
     *  Start scan position for gridded ATMS generation (index start with 0). Keep the 48 scans in center
     */
    final public static int INDEX_SCAN_POSITION_START = 24;  // keep similar swath width with Aqua

    /**
     *  End scan position for gridded FCDR generation (index start with 0).
     */
    final public static int INDEX_SCAN_POSITION_END = 71;
    
    /**
     * Variable name in L3 data file for BT from minimum view zenith angle
     */
    final public static String VAR_NAME_BT_MINVZA="BT_minvza";
    
    /**
     * Variable name in L3 data file for BT from block mean
     */
    final public static String VAR_NAME_BT_BLOCKMEAN="BT_mean";
    
    /**
     * variable name for BT standard deviation
     */
    final public static String VAR_NAME_BT_STD="BT_std";
    
    /**
     * Variable name for number of pixels within each grid
     */
    final public static String VAR_NAME_PIXELCOUNT="Pixel_count";
    
    /**
     * Variable name for minimum view zenith angle
     */
    final public static String VAR_NAME_MINVZA="vza_min";    
}
