/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.etc.AtmsLimbConstant.java
*
* NAME
*   atms.etc.AtmsLimbConstant.java
*
* PURPOSE
*   Defines constants for the ATMS  limb correction
* 
* DESCRIPTION
*	This class is used to define constants for ATMS  limb correction
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */
package atms.etc;

/**
 * This class is used to define constants for ATMS  limb correction
 * @author Xianjun Hao, George Mason University  
 */
public class AtmsLimbConstant {
    /**
     * Maximum number of associated channels
     */
    final public static int LUT_MAXIMUM_NUMBER_ASS = 3;
    
    /**
     * Number of ATMS channels
     */
    final  public static int ATMS_NUMBER_CHANNELS = 22;
    
    /**
     * Variable name for btm_land
     */
    final public static String LUT_VARNAME_BTM_LAND="/btm_land";

    /**
     * Variable name for btm_sea
     */
    final public static String LUT_VARNAME_BTM_SEA="/btm_sea";

    /**
     * Variable name for btm_ass_land
     */
    final public static String LUT_VARNAME_BTM_ASS_LAND="/btm_ass_land";

    /**
     * Variable name for btm_ass_sea
     */
    final public static String LUT_VARNAME_BTM_ASS_SEA="/btm_ass_sea";

    /**
     * Variable name for coef_limbcorr_land
     */
    final public static String LUT_VARNAME_COEF_LIMBCORR_LAND="/coef_limbcorr_land";
    
    /**
     * Variable name for coef_limbcorr_sea
     */
    final public static String LUT_VARNAME_COEF_LIMBCORR_SEA="/coef_limbcorr_sea";
    
    
    /**
     * Variable name for channels_associated
     */
    final public static String LUT_VARNAME_CHANNELS_ASS="/channels_associated";
    
    /**
     * Variable name for land_sea_mask
     */
    final public static String LUT_VARNAME_LAND_SEA_MASK = "/land_sea_mask";
    
    /**
     * Starting latitude of land/sea mask
     */
    final public static double LUT_LANDSEA_MASK_LATITUDE_START = 90.0d;
    
    /**
     *  Latitude resolution of land/sea mask
     */
    final public static double LUT_LANDSEA_MASK_LATITUDE_STEP = -0.05d;

    /**
     * Starting longitude of land/sea mask
     */
    final public static double LUT_LANDSEA_MASK_LONGITUDE_START = -180.0d;
    
    /**
     *  longitude resolution of land/sea mask
     */
    final public static double LUT_LANDSEA_MASK_LONGITUDE_STEP = 0.05d;

    /**
     * Dimension of latitude in Land/Sea Mask
     */
    final public static int LUT_LANDSEA_DIM_LATITUDE  = 3600;

    /**
     * Dimension of longitude in Land/Sea Mask
     */
    final public static int LUT_LANDSEA_DIM_LONGITUDE  = 7200;
    
    /**
     *  Threshold for land/sea 
     */
    final public static double THRESHOLD_LAND_SEA_FRACTION =0.5d;
    
    /**
     * Earth radius
     */
    final public static double EARTH_RADIUS = 6371.2d;
    
    final public static double ATMS_RES_LAND_SEA_FRACTION = 15.0;
    
    final public static double LAND_SEA_MASK_SLOPE = 20.0d;
    
    final public static int LAND_SEA_MASK_NRLA = 20;

    final public static int LAND_SEA_MASK_NRLO = 20;

    /**
     *  file name of ATMS Limb LUT
     */    
    final public static String FILENAME_LIMB_LUT="atms_limbcorr_lut.nc";
    
    /**
     *  file name of the land/sea mask for limb correction
     */
    final public static String FILENAME_LIMB_LANDSEA_MASK = "landsea_mask_05.nc";
        
}
