/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.etc.JPSSConstant.java
*
* NAME
*   atms.etc.JPSSConstant.java
*
* PURPOSE
*   Defines constants related to the JPSS mission
* 
* DESCRIPTION
*	This class is used to define constants related to the JPSS mission
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */
package atms.etc;

/**
 * Class to define constants related to JPS mission.
 * 
 * @author Xianjun Hao, George Mason University  
 */
public class JPSSConstant {
    
    /**
     * name of SNPP satellite
     */
    final public static String SATELLITE_NAME_SNPP="npp";
    
    /**
     * Name of NOAA-20 satellite
     */
    final public static String SATELLITE_NAME_N20="n20";
    
    /**
     * Name of J1 (N20)
     */
    final public static String SATELLITE_NAME_J01="j01";
    
    /**
     * File tag for SNPP 
     */
    final public static String SATELLITE_FILETAG_SNPP="npp";
    
    /**
     *  File tag for N20
     */
    final public static String SATELLITE_FILETAG_N20="j01";
    
    /**
     * File tag for J1 (N20)
     */
    final public static String SATELLITE_FILETAG_J01="j01";
    
    /**
     * Index for NPP
     */
    final public static int SATELLITE_INDEX_SNPP=0;
    
    /**
     * Index for N20
     */
    final public static int SATELLITE_INDEX_N20=1;
    
    /**
     * Index for J1
     */
    final public static int SATELLITE_INDEX_J01=1;
    
    /**
     * Satellite list
     */
    final public static String[] JPSS_SATELLITE_NAME_LIST= {SATELLITE_NAME_SNPP, SATELLITE_NAME_N20};

    /**
     * File tag list
     */
    final public static String[] JPSS_SATELLITE_FILETAG_LIST= {SATELLITE_FILETAG_SNPP, SATELLITE_FILETAG_N20};

    
    /**
     * Get satellite name from index
     * @param index, index of JPSS satellites
     * @return name of satellite
     */
    final public static String getJpssSatelliteName(int index) {
        if (index>=0) {
            return JPSS_SATELLITE_NAME_LIST[index];
        } else {
            return null;
        }
    }

    /**
     * Get satellite file tag from index
     * @param index, index of JPSS satellites
     * @return file tag for satellite
     */
    final public static String getJpssFileTag(int index) {
        if (index>=0) {
            return JPSS_SATELLITE_FILETAG_LIST[index];
        } else {
            return null;
        }
    }    
    /**
     * Get JPSS satellite index
     * @param satName
     * @return index (0, npp; 1, j01/n20; 2, j02/n21)
     */
    final public static int getJpssSatelliteIndex(String satName) {
        int index = -1;

        if (satName.equalsIgnoreCase(SATELLITE_NAME_SNPP)) {
            index = SATELLITE_INDEX_SNPP;
        } else {
            if ( (satName.equalsIgnoreCase(SATELLITE_NAME_N20)) |(satName.equalsIgnoreCase(SATELLITE_NAME_J01)) ) {
                index = SATELLITE_INDEX_N20;
            } else {
                index = -1;
            }
        }
                
        return index;
    }
}
