/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.util.DataUtility.java
*
* NAME
*   atms.util.DataUtility.java
*
* PURPOSE
*   Defines tools for reading ATMS data
* 
* DESCRIPTION
*	This class is used to define tools for reading ATMS data
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */

package atms.util;

import java.io.File;

/**
 * Utility functions for reading data from hdf5 file.
 *
 * @author Xianjun Hao, George Mason University  
 */
public class DataUtility {

    /**
     * Convert unsigned short to short. Java NetCDF4 API doesn't support reading of unsigned short/int/long, need conversion.
     *
     * @param vsigned signed value
     * @return unsigned short
     */
    public static int convertShort(short vsigned) {
        byte b1 = (byte) (vsigned & 0xff);
        byte b2 = (byte) ((vsigned >>> 8) & 0xff);
        return (b2 & 0xFF) << 8 | (b1 & 0xFF);
    }


}
