/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.cdr.MltCdrTaskConfig.java
*
* NAME
*   atms.cdr.MltCdrTaskConfig.java
*
* PURPOSE
*   To specify task parameters for MLT CDR generation
* 
* DESCRIPTION
*	This class is used to define parameters for MLT CDR generation
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */

package cdr;

/**
 * Configuration for the CDR production
 * @author <Xianjun Hao <xhao1@gmu.edu>
 */
public class MltCdrTaskConfig {
    /**
     * Year of ending time
     */
    public int yearEnd = 0;
    
    /**
     * month of ending time
     */
    public int monthEnd = 0;
    
    /**
     * Root directory for LUTs
     */
    public String dirLut;
    
    /**
     * Directory of L4 data
     */
    public String dirL4;
    
    /**
     * Directory of reference CDR data
     */
    public String dirRefCDR;
    
    /**
     * Directory of CDR data
     */
    public String dirMltCDR;

    /**
     *  Constructor.
     * @param yearEnd, year of end time.
     * @param monthEnd, month of end time.
     * @param dirLut, root directory of LUTs.
     * @param dirL4, directory of L4 data.
     * @param dirRefCDR, directory of reference CDR.
     * @param dirMltCDR, directory of CDR data. 
     */
    public MltCdrTaskConfig(int yearEnd, int monthEnd, String dirLut, String dirL4, String dirRefCDR, String dirMltCDR) {
        this.yearEnd = yearEnd;
        this.monthEnd = monthEnd;
        this.dirLut = dirLut;
        this.dirL4 = dirL4; 
        this.dirRefCDR = dirRefCDR;      
        this.dirMltCDR = dirMltCDR;
    } 
    
}
