/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.cdr.RefCdrTaskConfig.java
*
* NAME
*   atms.cdr.RefCdrTaskConfig.java
*
* PURPOSE
*   Configure Reference CDR directory structure and information
* 
* DESCRIPTION
*	This class is used to specify the parameters in generating Reference CDR.
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */
package cdr;


/**
 * Configuration of Reference CDR directory structure and information
 * @author Xianjun Hao 
 */
public class RefCdrTaskConfig {
    public int yearEnd = 0;
    public int monthEnd = 0;
    public String dirLut;
    public String dirL4;
    public String dirRefCDR;
    
    /**
     * Empty constructor
     */
    public RefCdrTaskConfig(){        
    }
    
    /**
     * Constructor with specified task information
     * @param yearEnd,  year of the data end time
     * @param monthEnd, month of the data end time
     * @param dirLut, directory of LUTs 
     * @param dirL4, directory of L4 data
     * @param dirRefCDR, output directory for the reference CDR  
     */
    public RefCdrTaskConfig(int yearEnd, int monthEnd, String dirLut, String dirL4, String dirRefCDR){
        this.yearEnd = yearEnd;
        this.monthEnd = monthEnd;
        this.dirLut = dirLut;
        this.dirL4 = dirL4;
        this.dirRefCDR = dirRefCDR;        
    }
    
}
