/*  Robodoc Markup Header
*@***h* MLT_CDR_V5/atms.cdr.ReferenceCDR.java
*
* NAME
*   atms.cdr.ReferenceCDR.java
*
* PURPOSE
*   Generate all Reference CDR 
* 
* DESCRIPTION
*	This main class is used to generate Reference CDRs using satellites with stable orbits.
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   10/16/2023 Initial Version prepared for NCEI
*
*@*****
 */
package cdr;

import java.io.File;

/**
 * Main class to generate reference CDRs
 * @author <Xianjun Hao <xhao1@gmu.edu>
 */
public class ReferenceCDR {
    /**
     * Task configuration
     */    
    private RefCdrTaskConfig taskConf = null;
    
    /**
     * Constructor
     * @param taskConf, task configuration 
     */
    public ReferenceCDR( RefCdrTaskConfig taskConf ) {
        this.taskConf = taskConf;
    }
    
    /**
     * Produce reference CDR
     */
    public void produceRefCDR(){
        ReferenceTMT objRtmt = new ReferenceTMT(taskConf);
        objRtmt.processCDR();
        ReferenceTUT objRtut = new ReferenceTUT(taskConf);
        objRtut.processCDR();
        ReferenceTLS objRtls = new ReferenceTLS(taskConf);
        objRtls.processCDR();        
    }
    
    
    /**
     *  Main for Reference CDRs
     * @param args 
     */
    public static void main(String[] args){
        int year2, month2;
        String dirLut, dirL4, dirRefCDR;
        String str;
        
        for (int i=0; i<args.length; i++) {
            System.out.println("args:" +args[i]);
        }
        
        if (args.length >=5){
            year2 = 2023;
            month2 = 12;
            dirLut = "/home/xhao/data/mltcdrv5/lut/ref/";
            dirL4 = "/home/xhao/data/mltcdrv5/data/L4/";
            dirRefCDR = "/home/xhao/data/mltcdrv5/data/rfcdr/";            
        }  else {
            int k = 0;
            year2 = Integer.parseInt(args[k++]);
            month2 = Integer.parseInt(args[k++]);
            
            str = args[k++];
            if (!str.endsWith(File.separator)) {
                str = str+File.separator;
            }            
            dirLut = str;
            
            str = args[k++];
            if (!str.endsWith(File.separator)) {
                str = str+File.separator;
            }                        
            dirL4 = str;

            str = args[k++];
            if (!str.endsWith(File.separator)) {
                str = str+File.separator;
            }                        
            dirRefCDR = str;
        }
        RefCdrTaskConfig taskConf = new RefCdrTaskConfig(year2, month2,dirLut,dirL4, dirRefCDR);
        ReferenceCDR app = new ReferenceCDR(taskConf);
        app.produceRefCDR();
    }
    
    
}
